==> improvements-2.0.1.tar.gz: improvements/src/ImprovementsBreadcrumbBuilder.php <==
<?php

namespace Drupal\improvements;

use Drupal\Core\Breadcrumb\Breadcrumb;
use Drupal\Core\Breadcrumb\BreadcrumbBuilderInterface;
use Drupal\Core\Breadcrumb\BreadcrumbManager;
use Drupal\Core\Routing\RequestContext;
use Drupal\Core\Routing\RouteMatch;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\taxonomy\TermInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Matcher\RequestMatcherInterface;

class ImprovementsBreadcrumbBuilder implements BreadcrumbBuilderInterface {

  use StringTranslationTrait;

  /**
   * The dynamic router service.
   *
   * @var \Symfony\Component\Routing\Matcher\RequestMatcherInterface
   */
  protected $router;

  /**
   * The router request context.
   *
   * @var \Drupal\Core\Routing\RequestContext
   */
  protected $request_context;

  /**
   * Service constructor.
   */
  public function __construct(RequestMatcherInterface $router, RequestContext $request_context) {
    $this->router = $router;
    $this->request_context = $request_context;
  }

  /**
   * {@inheritDoc}
   */
  public function applies(RouteMatchInterface $route_match) {
    $route_name = $route_match->getRouteName();

    // Term edit form
    if ($route_name == 'entity.taxonomy_term.edit_form') {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritDoc}
   */
  public function build(RouteMatchInterface $route_match) {
    $route_name = $route_match->getRouteName();

    // Breadcrumb for term edit form
    if ($route_name == 'entity.taxonomy_term.edit_form') {
      $term = $route_match->getParameter('taxonomy_term'); /** @var TermInterface $term */
      $breadcrumb = $this->getBreadcrumbForPath('/admin/structure/taxonomy/manage/' . $term->bundle() . '/overview/fields');
      $breadcrumb->addCacheContexts(['url.path']);
      return $breadcrumb;
    }
  }

  /**
   * Return breadcrumbs for path.
   *
   * @return Breadcrumb
   */
  protected function getBreadcrumbForPath(string $path) {
    // Create fake request
    $fake_request = Request::create($path);
    $fake_request_attributes = $this->router->matchRequest($fake_request);
    $fake_request->attributes->add($fake_request_attributes);

    // Create fake route match
    $fake_route_match = RouteMatch::createFromRequest($fake_request);

    // Change request context path to work PathBasedBreadcrumbBuilder
    $original_request_context_path_info = $this->request_context->getPathInfo();
    $this->request_context->setPathInfo($path);

    // Generate breadcrumb
    $breadcrumb_manager = \Drupal::service('breadcrumb'); /** @var BreadcrumbManager $breadcrumb_builder */
    $breadcrumb = $breadcrumb_manager->build($fake_route_match);

    // Restore request context path
    $this->request_context->setPathInfo($original_request_context_path_info);

    return $breadcrumb;
  }

}

==> improvements-2.0.3.tar.gz: improvements/src/ImprovementsBreadcrumbBuilder.php <==
<?php

namespace Drupal\improvements;

use Drupal\Core\Breadcrumb\Breadcrumb;
use Drupal\Core\Breadcrumb\BreadcrumbBuilderInterface;
use Drupal\Core\Breadcrumb\BreadcrumbManager;
use Drupal\Core\Link;
use Drupal\Core\Routing\RequestContext;
use Drupal\Core\Routing\RouteMatch;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\taxonomy\TermInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Routing\Matcher\RequestMatcherInterface;

class ImprovementsBreadcrumbBuilder implements BreadcrumbBuilderInterface {

  use StringTranslationTrait;

  /**
   * The dynamic router service.
   */
  protected RequestMatcherInterface $router;

  /**
   * The router request context.
   */
  protected RequestContext $request_context;

  /**
   * Service constructor.
   */
  public function __construct(RequestMatcherInterface $router, RequestContext $request_context) {
    $this->router = $router;
    $this->request_context = $request_context;
  }

  /**
   * {@inheritDoc}
   */
  public function applies(RouteMatchInterface $route_match): bool {
    $route_name = $route_match->getRouteName();

    return in_array($route_name, [
      'entity.taxonomy_term.edit_form',
      'entity.contact_form.canonical',
    ]);
  }

  /**
   * {@inheritDoc}
   */
  public function build(RouteMatchInterface $route_match): Breadcrumb {
    $route_name = $route_match->getRouteName();
    $links = [
      Link::createFromRoute($this->t('Home'), '<front>'),
    ];

    if ($route_name == 'entity.taxonomy_term.edit_form') {
      return $this->buildBreadcrumbTermEditForm($route_match);
    }

    $breadcrumb = new Breadcrumb();
    $breadcrumb->setLinks($links);
    return $breadcrumb;
  }

  /**
   * Build breadcrumb for "entity.taxonomy_term.edit_form" route.
   */
  protected function buildBreadcrumbTermEditForm(RouteMatchInterface $route_match): Breadcrumb {
    $term = $route_match->getParameter('taxonomy_term'); /** @var TermInterface $term */
    $breadcrumb = $this->getBreadcrumbForPath('/admin/structure/taxonomy/manage/' . $term->bundle() . '/overview/fields');
    $breadcrumb->addCacheContexts(['url.path']);
    return $breadcrumb;
  }

  /**
   * Return breadcrumbs for path.
   */
  protected function getBreadcrumbForPath(string $path): Breadcrumb {
    // Create fake request
    $fake_request = Request::create($path);
    $fake_request_attributes = $this->router->matchRequest($fake_request);
    $fake_request->attributes->add($fake_request_attributes);

    // Create fake route match
    $fake_route_match = RouteMatch::createFromRequest($fake_request);

    // Change request context path to work PathBasedBreadcrumbBuilder
    $original_request_context_path_info = $this->request_context->getPathInfo();
    $this->request_context->setPathInfo($path);

    // Generate breadcrumb
    $breadcrumb_manager = \Drupal::service('breadcrumb'); /** @var BreadcrumbManager $breadcrumb_builder */
    $breadcrumb = $breadcrumb_manager->build($fake_route_match);

    // Restore request context path
    $this->request_context->setPathInfo($original_request_context_path_info);

    return $breadcrumb;
  }

}
